# vim: sw=4:ts=4:et
#
# Copyright (c) 2013 Red Hat, Inc.

# This program and entire repository is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the License,
# or any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program.  If not, see <http://www.gnu.org/licenses/>.
#

%define selinux_variants targeted

%if 0%{?rhel} == 7
# absolute minimum versions for RHEL 7.1
%define selinux_policy_ver 3.13.1-7
%endif

%define moduletype apps
%define modulename fusor

# set and uncomment all three to set alpha tag
#global alphatag RC2
#global dotalphatag .%{alphatag}
#global dashalphatag -%{alphatag}

Name:           %{modulename}-selinux
Version:        1.0.6
Release:        1%{?dotalphatag}%{?dist}
Summary:        SELinux policy module for Foreman

Group:          System Environment/Base
License:        GPLv3+
URL:            http://www.theforeman.org
Source0:        %{name}-%{version}.tar.gz

BuildRequires:  checkpolicy, selinux-policy-devel, hardlink
BuildRequires:  policycoreutils
BuildRequires:  /usr/bin/pod2man
BuildArch:      noarch

Requires:           foreman-selinux
Requires:           selinux-policy >= %{selinux_policy_ver}
Requires(post):     /usr/sbin/semodule, /sbin/restorecon, /usr/sbin/setsebool, /usr/sbin/selinuxenabled, /usr/sbin/semanage
Requires(post):     policycoreutils-python
Requires(post):     selinux-policy-targeted
Requires(postun):   /usr/sbin/semodule, /sbin/restorecon

%description
SELinux policy module for Fusor

%prep
%setup -q -n %{name}-%{version}%{?dashalphatag}

%build
# create selinux-friendly version from VR and replace it inplace
perl -i -pe 'BEGIN { $VER = join ".", grep /^\d+$/, split /\./, "%{version}.%{release}"; } s!\@\@VERSION\@\@!$VER!g;' %{modulename}.te

# determine distribution name and version
%if 0%{?rhel} >= 6
    distver=rhel%{rhel}
%endif
%if 0%{?fedora} >= 18
    distver=fedora%{fedora}
%endif

# build policy
for selinuxvariant in %{selinux_variants}
do
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile DISTRO=${distver}
    bzip2 -9 %{modulename}.pp
    mv %{modulename}.pp.bz2 %{modulename}.ppbz2.${selinuxvariant}
    make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean DISTRO=${distver}
done

%install
# install policy modules
for selinuxvariant in %{selinux_variants}
  do
    install -d %{buildroot}%{_datadir}/selinux/${selinuxvariant}
    install -p -m 644 %{modulename}.ppbz2.${selinuxvariant} \
        %{buildroot}%{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp.bz2
  done

# install interfaces
install -d %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}
install -p -m 644 %{modulename}.if %{buildroot}%{_datadir}/selinux/devel/include/%{moduletype}/%{modulename}.if

# hardlink identical policy module packages together
/usr/sbin/hardlink -cv %{buildroot}%{_datadir}/selinux

%post
for selinuxvariant in %{selinux_variants}
do
  /usr/sbin/semodule -s ${selinuxvariant} -i \
    %{_datadir}/selinux/${selinuxvariant}/%{modulename}.pp.bz2 > /dev/null
done

%postun
if [ $1 -eq 0 ] ; then
  for selinuxvariant in %{selinux_variants}
  do
    /usr/sbin/semodule -s ${selinuxvariant} -r %{modulename} > /dev/null
  done
fi

%files
%attr(0600,root,root) %{_datadir}/selinux/*/%{modulename}.pp.bz2
%{_datadir}/selinux/devel/include/%{moduletype}/%{modulename}.if

%changelog
* Tue Aug 30 2016 jesus m. rodriguez <jesusr@redhat.com> 1.0.6-1
- 1368575 - Added further gluster permissions (dymurray@redhat.com)

* Fri Aug 26 2016 jesus m. rodriguez <jesusr@redhat.com> 1.0.5-1
- 1368575 - Added more permissions for GlusterFS to mount shares (#33) (dymurray@redhat.com)

* Thu Aug 25 2016 jesus m. rodriguez <jesusr@redhat.com> 1.0.4-1
- 1368575 - Added selinux policy for GlusterFS to be able to check mount points (dymurray@redhat.com)
* Thu Aug 11 2016 Jason Montleon <jmontleo@redhat.com> 1.0.3-1
- add open to dir class (jmontleo@redhat.com)

* Thu Aug 11 2016 jesus m. rodriguez <jesusr@redhat.com> 1.0.2-1
- use VersionTagger (jesusr@redhat.com)

* Wed Aug 10 2016 John Matthews <jwmatthews@gmail.com> 1.0.1-11
- 1320078 - Added open capability for passenger_t reading NFS shares
  (dymurray@redhat.com)

* Fri Aug 05 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-10
- add workaround for dhcp errors (jmontleo@redhat.com)
- 1320078 - Added read and mounton capability for passenger_t reading NFS
  shares (#27) (dymurray@redhat.com)

* Fri Jul 22 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-9
- Remove bogus policycoreutils version from rpm spec (#25)
  (jmontleo@redhat.com)

* Mon Jul 18 2016 John Matthews <jwmatthews@gmail.com> 1.0.1-8
- Added rule for foreman user to access /var/log/messages
  (jinmaster923@gmail.com)

* Wed Jun 29 2016 John Matthews <jwmatthews@gmail.com> 1.0.1-7
- 1309600 - Added rules for access to candlepin.log (jinmaster923@gmail.com)

* Mon Jun 20 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-6
- Fix OSE available storage check (jmontleo@redhat.com)

* Tue May 17 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-5
- 

* Wed May 11 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-4
- fix bad merge (jmontleo@redhat.com)

* Wed May 11 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-3
- allow sys-filesystem/ffi to load (jmontleo@redhat.com)

* Fri May 06 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-2
- Added ssh_keygen_exec_t type. (jinmaster923@gmail.com)
- Added read to class dir (jinmaster923@gmail.com)
- Added rules for Openshift (jinmaster923@gmail.com)
- update releaser (jmontleo@redhat.com)

* Thu Mar 24 2016 Jason Montleon <jmontleo@redhat.com> 1.0.1-1
- allow glance port (jmontleo@redhat.com)

* Mon Feb 15 2016 Jason Montleon <jmontleo@redhat.com> 1.0.0-15
- require foreman-selinux for foreman_log_t (jmontleo@redhat.com)

* Fri Feb 12 2016 Jason Montleon <jmontleo@redhat.com> 1.0.0-14
- fix additional nfs denial (jmontleo@redhat.com)

* Mon Dec 07 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-13
- add create permission for dir class for log rule (jmontleo@redhat.com)

* Mon Dec 07 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-12
- allow log creation (jmontleo@redhat.com)

* Tue Dec 01 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-11
- add module request for nfs (jmontleo@redhat.com)

* Mon Nov 30 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-10
- additional nfs rules (jmontleo@redhat.com)

* Mon Nov 30 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-9
- additional nfs rules (jmontleo@redhat.com)

* Mon Nov 30 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-8
- add additional rules for nfs checks (jmontleo@redhat.com)

* Mon Nov 30 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-7
- add selinux support for nfs checks (jmontleo@redhat.com)

* Wed Nov 11 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-6
- let passenger connect to keystone and neutron (jmontleo@redhat.com)

* Tue Nov 10 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-5
- add class file write (jmontleo@redhat.com)

* Tue Nov 10 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-4
  (jmontleo@redhat.com)
- allow write so we can fetch the rsa key (jmontleo@redhat.com)

* Thu Oct 22 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-3
- Automatic commit of package [fusor-selinux] minor release [1.0.0-1].
  (jmontleo@redhat.com)

* Wed Oct 21 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-2
- allow connecting to the undercloud host (jmontleo@redhat.com)

* Thu Jul 23 2015 Jason Montleon <jmontleo@redhat.com> 1.0.0-1
- new package built with tito

